summaryrefslogtreecommitdiff
path: root/include/command_parse.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/command_parse.h')
-rw-r--r--include/command_parse.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/command_parse.h b/include/command_parse.h
index 8324e5e25..f5cb47620 100644
--- a/include/command_parse.h
+++ b/include/command_parse.h
@@ -34,10 +34,11 @@ class CoreExport CommandParser
private:
/** Process a command from a user.
* @param user The user to parse the command for
* @param cmd The command string to process
*/
- void ProcessCommand(LocalUser* user, std::string& cmd);
+ void ProcessCommand(LocalUser* user, std::string& command, Command::Params& parameters);
/** Command list, a hash_map of command names to Command*
*/
@@ -116,7 +117,7 @@ class CoreExport CommandParser
* @param buffer The buffer line to process
* @param user The user to whom this line belongs
*/
- void ProcessBuffer(std::string &buffer,LocalUser *user);
+ void ProcessBuffer(LocalUser* user, const std::string& buffer);
/** Add a new command to the commands hash
* @param f The new Command to add to the list
@@ -34,10 +34,11 @@ class CoreExport CommandParser
private:
/** Process a command from a user.
- * @param user The user to parse the command for
- * @param cmd The command string to process
+ * @param user The user to parse the command for.
+ * @param command The name of the command.
+ * @param parameters The parameters to the command.
*/